aboutsummaryrefslogtreecommitdiff
path: root/src/util.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/util.rs')
-rw-r--r--src/util.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/util.rs b/src/util.rs
index ccec5e6..315cb34 100644
--- a/src/util.rs
+++ b/src/util.rs
@@ -19,7 +19,7 @@ pub enum CommandError {
/// You are not authorized for this command or provided a wrong temporary
/// password.
NotAuthorized,
/// An error occured when getting or setting the time.
Timestamp,
/// You did not provide a name for the OTP slot.
NoName,
@@ -29,7 +29,7 @@ pub enum CommandError {
UnknownCommand,
/// AES decryption failed.
AesDecryptionFailed,
/// An unknown error occured.
Unknown,
/// You passed a string containing a null byte.
InvalidString,
@@ -117,12 +117,12 @@ impl fmt::Display for CommandError {
CommandError::NotAuthorized => {
"You are not authorized for this command or provided a wrong temporary password"
}
- CommandError::Timestamp => "An error occured when getting or setting the time",
+ CommandError::Timestamp => "An error occurred when getting or setting the time",
CommandError::NoName => "You did not provide a name for the OTP slot",
CommandError::NotSupported => "This command is not supported by this device",
CommandError::UnknownCommand => "This command is unknown",
CommandError::AesDecryptionFailed => "AES decryption failed",
- CommandError::Unknown => "An unknown error occured",
+ CommandError::Unknown => "An unknown error occurred",
CommandError::InvalidString => "You passed a string containing a null byte",
CommandError::InvalidSlot => "The given slot is invalid",
};
@@ -19,7 +19,7 @@ pub enum CommandError {
/// password.
NotAuthorized,
- /// An error occured when getting or setting the time.
+ /// An error occurred when getting or setting the time.
Timestamp,
/// You did not provide a name for the OTP slot.
@@ -29,7 +29,7 @@ pub enum CommandError {
/// AES decryption failed.
AesDecryptionFailed,
- /// An unknown error occured.
+ /// An unknown error occurred.
Unknown,
/// You passed a string containing a null byte.